---
title: "parseNumberPattern"
parent: "@messageformat/number-skeleton"
grand_parent: API Reference
---

<!-- Do not edit this file. It is automatically generated by API Documenter. -->



# parseNumberPattern() function

Parse an [ICU NumberFormatter pattern](http://unicode.org/reports/tr35/tr35-numbers.html#Number_Format_Patterns) string into a [Skeleton](./number-skeleton.skeleton.md) structure.

<b>Signature:</b>

```typescript
export declare function parseNumberPattern(src: string, currency?: string | null, onError?: (error: NumberFormatError) => void): Skeleton;
```

## Parameters

|  Parameter | Type | Description |
|  --- | --- | --- |
|  src | string | The pattern string |
|  currency | string \| null | If the pattern includes ¤ tokens, their skeleton representation requires a three-letter currency code. |
|  onError | (error: [NumberFormatError](./number-skeleton.numberformaterror.md)<!-- -->) =&gt; void | Called when the parser encounters a syntax error. The function will still return a [Skeleton](./number-skeleton.skeleton.md)<!-- -->, but it will be incomplete and/or inaccurate. If not defined, the error will be thrown instead. |

<b>Returns:</b>

[Skeleton](./number-skeleton.skeleton.md)

## Remarks

Unlike the skeleton parser, the pattern parser is not able to return partial results on error, and will instead throw. Output padding is not supported.

## Example


```js
import { parseNumberPattern } from '@messageformat/number-skeleton'

parseNumberPattern('#,##0.00 ¤', 'EUR', console.error)
// {
//   group: 'group-auto',
//   precision: {
//     style: 'precision-fraction',
//     minFraction: 2,
//     maxFraction: 2
//   },
//   unit: { style: 'currency', currency: 'EUR' }
// }

```

